@@ -1,7 +1,7 @@
 package File::Write::Rotate;
 
-our $DATE = '2015-10-20'; # DATE
-our $VERSION = '0.29'; # VERSION
+our $DATE = '2016-10-07'; # DATE
+our $VERSION = '0.31'; # VERSION
 
 use 5.010001;
 use strict;
@@ -10,7 +10,6 @@ use warnings;
 # we must not use Log::Any, looping if we are used as log output
 #use Log::Any '$log';
 
-use Carp;
 use File::Spec;
 use IO::Compress::Gzip qw(gzip $GzipError);
 use Scalar::Util qw(weaken);
@@ -26,9 +25,9 @@ sub new {
     my %args;
 
     defined($args{dir} = delete $args0{dir})
-        or croak "Please specify dir";
+        or die "Please specify dir";
     defined($args{prefix} = delete $args0{prefix})
-        or croak "Please specify prefix";
+        or die "Please specify prefix";
     $args{suffix} = delete($args0{suffix}) // "";
 
     $args{size} = delete($args0{size}) // 0;
@@ -36,14 +35,14 @@ sub new {
     $args{period} = delete($args0{period});
     if ($args{period}) {
         $args{period} =~ /\A(daily|day|month|monthly|year|yearly)\z/
-            or croak "Invalid period, please use daily/monthly/yearly";
+            or die "Invalid period, please use daily/monthly/yearly";
     }
 
     for (map {"hook_$_"} qw(before_rotate after_rotate after_create
                             before_write a)) {
         next unless $args0{$_};
         $args{$_} = delete($args0{$_});
-        croak "Invalid $_, please supply a coderef"
+        die "Invalid $_, please supply a coderef"
             unless ref($args{$_}) eq 'CODE';
     }
 
@@ -59,16 +58,16 @@ sub new {
 
     $args{lock_mode} = delete($args0{lock_mode}) // 'write';
     $args{lock_mode} =~ /\A(none|write|exclusive)\z/
-        or croak "Invalid lock_mode, please use none/write/exclusive";
+        or die "Invalid lock_mode, please use none/write/exclusive";
 
     $args{rotate_probability} = delete($args0{rotate_probability});
     if (defined $args{rotate_probability}) {
         $args{rotate_probability} > 0 && $args{rotate_probability} < 1.0
-            or croak "Invalid rotate_probability, must be 0 < x < 1";
+            or die "Invalid rotate_probability, must be 0 < x < 1";
     }
 
     if (keys %args0) {
-        croak "Unknown arguments to new(): ".join(", ", sort keys %args0);
+        die "Unknown arguments to new(): ".join(", ", sort keys %args0);
     }
 
     $args{_buffer} = [];
@@ -386,7 +385,7 @@ sub write {
                 (
                     @{ $self->{_buffer} }
                     ? " (buffer is full, "
-                      . ~~@{ $self->{_buffer} }
+                      . scalar(@{ $self->{_buffer} })
                       . " message(s))"
                     : ""
                 ),
@@ -400,13 +399,13 @@ sub write {
 sub compress {
     my ($self) = shift;
 
-    require Proc::PID::File;
-
     my $lock           = $self->_get_lock;
     my $files_ref        = $self->_get_files;
     my $done_compression = 0;
 
     if (@{$files_ref}) {
+        require Proc::PID::File;
+
         my $pid = Proc::PID::File->new(
             dir    => $self->{dir},
             name   => "$self->{prefix}-compress",
@@ -466,7 +465,7 @@ File::Write::Rotate - Write to files that archive/rotate themselves
 
 =head1 VERSION
 
-This document describes version 0.29 of File::Write::Rotate (from Perl distribution File-Write-Rotate), released on 2015-10-20.
+This document describes version 0.31 of File::Write::Rotate (from Perl distribution File-Write-Rotate), released on 2016-10-07.
 
 =head1 SYNOPSIS
 
@@ -579,6 +578,9 @@ Since this is called indirectly by write(), locking is also already done.
 
 =head2 binmode => str
 
+Will call C<binmode()> (see L<perlfunc>) on the opened file handle. With this
+option you can set binary mode (e.g. on Windows) or set PerlIO layer(s).
+
 =head1 METHODS
 
 =head2 $obj = File::Write::Rotate->new(%args)
@@ -751,6 +753,22 @@ file sizes will exceed for a bit if you do size-based rotation. More suitable if
 you only do size-based rotation since it is usually okay to exceed sizes for a
 bit.
 
+=head1 HOMEPAGE
+
+Please visit the project's homepage at L<https://metacpan.org/release/File-Write-Rotate>.
+
+=head1 SOURCE
+
+Source repository is at L<https://github.com/perlancar/perl-File-Write-Rotate>.
+
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=File-Write-Rotate>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
 =head1 SEE ALSO
 
 L<Log::Dispatch::FileRotate>, which inspires this module. Differences between
@@ -789,29 +807,13 @@ slightly faster than LDFR on my testing).
 L<Tie::Handle::FileWriteRotate> and Log::Dispatch::FileWriteRotate, which use
 this module.
 
-=head1 HOMEPAGE
-
-Please visit the project's homepage at L<https://metacpan.org/release/File-Write-Rotate>.
-
-=head1 SOURCE
-
-Source repository is at L<https://github.com/perlancar/perl-File-Write-Rotate>.
-
-=head1 BUGS
-
-Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=File-Write-Rotate>
-
-When submitting a bug or request, please include a test-file or a
-patch to an existing test-file that illustrates the bug or desired
-feature.
-
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by perlancar@cpan.org.
+This software is copyright (c) 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
